@@ -38,13 +38,24 @@ Description
 Implementation of Spectral Methods in 1 dimension.
 
 Available polynomials:
-    * :ref:`ref_jacobi`
-    * Hermite Physicist
-    * Hermite Function
-    * Hermite Probabilistic
-    * Laguerre Polynomial
-    * Laguerre Function
-    * ORTHPOL package (generation of recursion coefficients using [4]_)
+    * :ref:`ref_jacobi` or ``Spectral1D.JACOBI``
+    * Hermite Physicist or ``Spectral1D.HERMITEP``
+    * Hermite Function or ``Spectral1D.HERMITEF``
+    * Hermite Probabilistic or ``Spectral1D.HERMITEP_PROB``
+    * Laguerre Polynomial or ``Spectral1D.LAGUERREP``
+    * Laguerre Function or ``Spectral1D.LAGUERREF``
+    * ORTHPOL package (generation of recursion coefficients using [4]_)  or ``Spectral1D.ORTHPOL``
+
+Available quadrature rules (related to selected polynomials):
+    * Gauss or ``Spectral1D.GAUSS``
+    * Gauss-Lobatto or ``Spectral1D.GAUSSLOBATTO``
+    * Gauss-Radau or ``Spectral1D.GAUSSRADAU``
+
+Available quadrature rules (without polynomial selection):
+    * Kronrod-Patterson on the real line or ``Spectral1D.KPN`` (function ``Spectral1D.kpn(n)``)
+    * Kronrod-Patterson uniform or ``Spectral1D.KPU`` (function ``Spectral1D.kpu(n)``)
+    * Clenshaw-Curtis or ``Spectral1D.CC`` (function ``Spectral1D.cc(n)``)
+    * Fejer's or ``Spectral1D.FEJ`` (function ``Spectral1D.fej(n)``)
 
 .. _ref_jacobi:
 
@@ -115,6 +126,8 @@ from scipy.misc import factorial
 from scipy.misc import comb as SPcomb
 from scipy import sparse as scsp
 
+import SparseGrids as SG
+
 JACOBI = 'Jacobi'
 HERMITEP = 'HermiteP'
 HERMITEF = 'HermiteF'
@@ -127,12 +140,18 @@ AVAIL_POLY = [JACOBI, HERMITEP, HERMITEF, HERMITEP_PROB, LAGUERREP, LAGUERREF, O
 GAUSS = 'Gauss'
 GAUSSRADAU = 'GaussRadau'
 GAUSSLOBATTO = 'GaussLobatto'
-AVAIL_QUADPOINTS = [GAUSS, GAUSSRADAU, GAUSSLOBATTO]
+GQU = 'Gauss Uniform'
+GQN = 'Gauss Normal'
+KPU = 'Kronrod-Patterson Uniform'
+KPN = 'Kronrod-Patterson Normal'
+CC  = 'Clenshaw-Curtis Uniform'
+FEJ = 'Fejer Uniform'
+AVAIL_QUADPOINTS = [GAUSS, GAUSSRADAU, GAUSSLOBATTO, GQU, GQN, KPU, KPN, CC, FEJ]
 
 class Poly1D(object):
-    poly = []
-    params = []
-    sdout = []
+    poly = None
+    params = None
+    sdout = None
 
     def __init__(self,poly,params,sdout=sys.stderr):
         """
@@ -741,6 +760,18 @@ class Poly1D(object):
             return self.GaussLobattoQuadrature(N,normed,left,right)
         elif quadType == GAUSSRADAU:
             return self.GaussRadauQuadrature(N,normed,end)
+        elif quadType in AVAILQUADPOINTS:
+            if self.poly == HERMITE and (quadType in [GQN,KPN]):
+                if quadType == GQN: return gqn(N)
+                if quadType == KPN: return kpn(N)
+            if self.poly == JACOBI and (quadType in [GQU,KPU,CC,FEJ]):
+                if quadType == GQU: return gqu(N,norm=normed)
+                if quadType == KPU: return kpu(N,norm=normed)
+                if quadType == CC:  return cc(N,norm=normed)
+                if quadType == FEJ: return fej(N,norm=normed)
+                
+        else:
+            raise AttributeError("The selected type of quadrature rule is not available")
     
     def GaussQuadrature(self,N,normed=False):
         """
@@ -2143,3 +2174,147 @@ def SparseLinearInterpolationMatrix(x,xi):
 
     M = scsp.coo_matrix( (np.asarray(vals), (np.asarray(rows),np.asarray(cols))), shape=( len(xi), len(x) ) )
     return M
+
+def gqu(N,norm=True):
+    """
+    GQU(): function for generating 1D Gaussian quadrature rules for unweighted integral over [-1,1] (Gauss-Legendre)
+
+    Note:: Max ``N'' is 25
+
+    Syntax:
+        (n,w) = GQU(l)
+    Input:
+        l = level of accuracy of the quadrature rule
+    Output:
+        n = nodes
+        w = weights
+    """
+    (x,w) = SG.GQU(N)
+    if (N % 2 == 0):
+        x = np.asarray(x)
+        x = np.hstack([1-x[::-1],x])
+        w = np.asarray(w)
+        w = np.hstack([w[::-1],w])
+    else:
+        x = np.asarray(x)
+        x = np.hstack([1-x[1:][::-1],x])
+        w = np.asarray(w)
+        w = np.hstack([w[1:][::-1],w])
+    
+    x = x*2. - 1.
+    if not norm: w *= 2.
+    return (x,w)
+
+def gqn(N):
+    """
+    GQN(): function for generating 1D Gaussian quadrature for integral with Gaussian weight (Gauss-Hermite)
+
+    Note:: Max ``N'' is 25
+
+    Syntax:
+        (n,w) = GQU(l)
+    Input:
+        l = level of accuracy of the quadrature rule
+    Output:
+        n = nodes
+        w = weights
+    """
+    (x,w) = SG.GQN(N)
+    if (N % 2 == 0):
+        x = np.asarray(x)
+        x = np.hstack([-x[::-1],x])
+        w = np.asarray(w)
+        w = np.hstack([w[::-1],w])
+    else:
+        x = np.asarray(x)
+        x = np.hstack([-x[1:][::-1],x])
+        w = np.asarray(w)
+        w = np.hstack([w[1:][::-1],w])
+    return (x,w)
+
+def kpu(N,norm=True):
+    """
+    KPU(): function for generating 1D Nested rule for unweighted integral over [-1,1]
+
+    Note:: Max ``N'' is 25
+
+    Syntax:
+        (n,w) = GQU(l)
+    Input:
+        l = level of accuracy of the quadrature rule
+    Output:
+        n = nodes
+        w = weights
+    """
+    (x,w) = SG.KPU(N)
+    x = np.asarray(x)
+    x = np.hstack([1-x[1:][::-1],x])
+    x = x*2. - 1.
+    w = np.asarray(w)
+    w = np.hstack([w[1:][::-1],w])
+    if not norm: w *= 2.
+    return (x,w)
+
+def kpn(N):
+    """
+    KPN(): function for generating 1D Nested rule for integral with Gaussian weight
+
+    Note:: Max ``N'' is 25
+
+    Syntax:
+        (n,w) = GQU(l)
+    Input:
+        l = level of accuracy of the quadrature rule
+    Output:
+        n = nodes
+        w = weights
+    """
+    (x,w) = SG.KPN(N)
+    x = np.asarray(x)
+    x = np.hstack([-x[1:][::-1],x])
+    w = np.asarray(w)
+    w = np.hstack([w[1:][::-1],w])
+    return (x,w)
+
+def cc(N,norm=True):
+    """
+    cc(): function for generating 1D Nested Clenshaw-Curtis [-1,1]
+
+    Syntax:
+        (n,w) = cc(N)
+    Input:
+        N = level of accuracy of the quadrature rule
+    Output:
+        n = nodes
+        w = weights
+    """
+    (x,w) = SG.CC(N)
+    x = np.hstack([-x[1:][::-1],x])
+    w = np.hstack([w[1:][::-1],w])
+    if norm: w /= np.sum(w)
+    return (x,w)
+
+def fej(N,norm=True):
+    """
+    fej(): function for generating 1D Nested Fejer's rule [-1,1]
+
+    Syntax:
+        (n,w) = fej(N)
+    Input:
+        N = level of accuracy of the quadrature rule
+    Output:
+        n = nodes
+        w = weights
+    """
+    (x,w) = SG.FEJ(N)
+    x = np.hstack([-x[1:][::-1],x])
+    w = np.hstack([w[1:][::-1],w])
+    if norm: w /= np.sum(w)
+    return (x,w)
+
+QUADS = {GQU: gqu,
+         GQN: gqn,
+         KPU: kpu,
+         KPN: kpn,
+         CC: cc,
+         FEJ: fej}
