@@ -39,15 +39,6 @@ It uses the package ``Spectral1D`` as basic polynomials in order to construct hi
 
 """
 
-__revision__ = filter(str.isdigit, "$Revision: 97 $")
-
-__author__ = "Daniele Bigoni"
-__copyright__ = """Copyright 2012, Daniele Bigoni"""
-__credits__ = ["Daniele Bigoni"]
-__maintainer__ = "Daniele Bigoni"
-__email__ = "dabi@imm.dtu.dk"
-__status__ = "Production"
-
 import numpy as np
 
 from scipy.misc import comb
